about summary refs log tree commit diff
path: root/editor/specialty/pnmmercator.c
diff options
context:
space:
mode:
Diffstat (limited to 'editor/specialty/pnmmercator.c')
-rw-r--r--editor/specialty/pnmmercator.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/editor/specialty/pnmmercator.c b/editor/specialty/pnmmercator.c
index af31d16d..cd9ff19b 100644
--- a/editor/specialty/pnmmercator.c
+++ b/editor/specialty/pnmmercator.c
@@ -56,7 +56,7 @@ parseCommandLine(int                        argc,
 
     optEntry * option_def;
     optStruct3 opt;
         /* Instructions to optParseOptions3 on how to parse our options. */
     
     unsigned int option_def_index;
 
@@ -73,7 +73,7 @@ parseCommandLine(int                        argc,
     opt.allowNegNum = FALSE;   /* We have no parms that are negative numbers */
 
     /* Uses and sets argc, argv, and some of *cmdlineP and others. */
-    optParseOptions3( &argc, (char **)argv, opt, sizeof(opt), 0 );
+    pm_optParseOptions3( &argc, (char **)argv, opt, sizeof(opt), 0 );
 
     /* Only parameter allowed is optional filespec */
     if (argc-1 < 1)
@@ -56,7 +56,7 @@ parseCommandLine(int                        argc,
     optEntry * option_def;
     optStruct3 opt;
-        /* Instructions to optParseOptions3 on how to parse our options. */
+        /* Instructions to pm_optParseOptions3 on how to parse our options. */
     
     unsigned int option_def_index;